@@ -4,6 +4,7 @@ from copy import deepcopy
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Any, Dict
+from uuid import UUID
 
 from ctlml_commons.entity.execution_type import ExecutionType
 from ctlml_commons.entity.order import OrderType
@@ -15,7 +16,8 @@ from ctlml_commons.util.num_utils import convert_floats
 @dataclass(frozen=True)
 class ExecutionRequest:
     investor_name: str
-    lot_id: str
+    lot_id: UUID
+    symbol: str
     execution_type: ExecutionType
     order_type: OrderType
     quantity: float
